==> msal-1.6.0-sources.jar: com/microsoft/identity/client/AzureCloudInstance.java <==
//  Copyright (c) Microsoft Corporation.
//  All rights reserved.
//
//  This code is licensed under the MIT License.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files(the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions :
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
package com.microsoft.identity.client;

/**
 * The clouds that can be used for Authority when making token requests in MSAL
 */
public enum AzureCloudInstance {

    /**
     * Microsoft Azure public cloud. Maps to https://login.microsoftonline.com
     */
    AzurePublic("https://login.microsoftonline.com"),

    /**
     * Microsoft Chinese national cloud. Maps to https://login.partner.microsoftonline.cn
     */
    AzureChina("https://login.partner.microsoftonline.cn"),

    /**
     * Microsoft German national cloud (“Black Forest”). Maps to https://login.microsoftonline.de
     */
    AzureGermany("https://login.microsoftonline.de"),

    /**
     * US Government cloud. Maps to https://login.microsoftonline.us
     */
    AzureUsGov("https://login.microsoftonline.us");

    private String cloudInstanceUri;

    AzureCloudInstance(String cloudInstanceUri) {
        this.cloudInstanceUri = cloudInstanceUri;
    }

    public String getCloudInstanceUri() {
        return cloudInstanceUri;
    }
}

==> msal-5.2.1-sources.jar: com/microsoft/identity/client/AzureCloudInstance.java <==
//  Copyright (c) Microsoft Corporation.
//  All rights reserved.
//
//  This code is licensed under the MIT License.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files(the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions :
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
package com.microsoft.identity.client;

/**
 * The clouds that can be used for Authority when making token requests in MSAL.
 */
public enum AzureCloudInstance {

    /**
     * Microsoft Azure public cloud.
     * Maps to https://login.microsoftonline.com.
     */
    AzurePublic("https://login.microsoftonline.com"),

    /**
     * Microsoft Chinese national cloud.
     * Maps to https://login.partner.microsoftonline.cn.
     */
    AzureChina("https://login.partner.microsoftonline.cn"),

    /**
     * Microsoft German national cloud (Black Forest).
     * Maps to https://login.microsoftonline.de.
     */
    AzureGermany("https://login.microsoftonline.de"),

    /**
     * US Government cloud.
     * Maps to https://login.microsoftonline.us.
     */
    AzureUsGov("https://login.microsoftonline.us");

    private String cloudInstanceUri;

    AzureCloudInstance(String cloudInstanceUri) {
        this.cloudInstanceUri = cloudInstanceUri;
    }

    public String getCloudInstanceUri() {
        return cloudInstanceUri;
    }
}
